@@ -16,6 +16,9 @@
  ***	Imports
  ***/
 
+#include <inttypes.h>
+#include <stdbool.h>
+
 #include <isc/lang.h>
 #include <isc/magic.h>
 
@@ -112,7 +115,7 @@
 #define DNS_MESSAGE_REPLYPRESERVE	(DNS_MESSAGEFLAG_RD|DNS_MESSAGEFLAG_CD)
 #define DNS_MESSAGEEXTFLAG_REPLYPRESERVE (DNS_MESSAGEEXTFLAG_DO)
 
-#define DNS_MESSAGE_HEADERLEN		12 /*%< 6 isc_uint16_t's */
+#define DNS_MESSAGE_HEADERLEN		12 /*%< 6 uint16_t's */
 
 #define DNS_MESSAGE_MAGIC		ISC_MAGIC('M','S','G','@')
 #define DNS_MESSAGE_VALID(msg)		ISC_MAGIC_VALID(msg, DNS_MESSAGE_MAGIC)
@@ -175,7 +178,7 @@ typedef int dns_messagetextflag_t;
 #define DNS_MESSAGERENDER_PARTIAL	0x0002	/*%< allow a partial rdataset */
 #define DNS_MESSAGERENDER_OMITDNSSEC	0x0004	/*%< omit DNSSEC records */
 #define DNS_MESSAGERENDER_PREFER_A	0x0008	/*%< prefer A records in
-						      additional section. */
+						     additional section. */
 #define DNS_MESSAGERENDER_PREFER_AAAA	0x0010	/*%< prefer AAAA records in
 						  additional section. */
 #define DNS_MESSAGERENDER_FILTER_AAAA	0x0020	/*%< filter AAAA records */
@@ -226,7 +229,7 @@ struct dns_message {
 	unsigned int			sig_reserved;
 	unsigned int			reserved; /* reserved space (render) */
 
-	isc_uint16_t			padding;
+	uint16_t			padding;
 	unsigned int			padding_off;
 
 	isc_buffer_t		       *buffer;
@@ -266,8 +269,8 @@ struct dns_message {
 };
 
 struct dns_ednsopt {
-	isc_uint16_t			code;
-	isc_uint16_t			length;
+	uint16_t			code;
+	uint16_t			length;
 	unsigned char			*value;
 };
 
@@ -1005,7 +1008,7 @@ dns_message_peekheader(isc_buffer_t *source, dns_messageid_t *idp,
  */
 
 isc_result_t
-dns_message_reply(dns_message_t *msg, isc_boolean_t want_question_section);
+dns_message_reply(dns_message_t *msg, bool want_question_section);
 /*%<
  * Start formatting a reply to the query in 'msg'.
  *
@@ -1029,7 +1032,7 @@ dns_message_reply(dns_message_t *msg, isc_boolean_t want_question_section);
  *\li	#DNS_R_FORMERR		-- the header or question section of the
  *				   message is invalid, replying is impossible.
  *				   If DNS_R_FORMERR is returned when
- *				   want_question_section is ISC_FALSE, then
+ *				   want_question_section is false, then
  *				   it's the header section that's bad;
  *				   otherwise either of the header or question
  *				   sections may be bad.
@@ -1375,17 +1378,25 @@ dns_message_gettimeadjust(dns_message_t *msg);
  */
 
 void
-dns_message_logpacket(dns_message_t *message,
-		      const char *description, const isc_sockaddr_t *address,
+dns_message_logpacket(dns_message_t *message, const char *description,
 		      isc_logcategory_t *category, isc_logmodule_t *module,
 		      int level, isc_mem_t *mctx);
-
+void
+dns_message_logpacket2(dns_message_t *message,
+		       const char *description, const isc_sockaddr_t *address,
+		       isc_logcategory_t *category, isc_logmodule_t *module,
+		       int level, isc_mem_t *mctx);
 void
 dns_message_logfmtpacket(dns_message_t *message, const char *description,
-			 const isc_sockaddr_t *address,
 			 isc_logcategory_t *category, isc_logmodule_t *module,
 			 const dns_master_style_t *style, int level,
 			 isc_mem_t *mctx);
+void
+dns_message_logfmtpacket2(dns_message_t *message, const char *description,
+			  const isc_sockaddr_t *address,
+			  isc_logcategory_t *category, isc_logmodule_t *module,
+			  const dns_master_style_t *style, int level,
+			  isc_mem_t *mctx);
 /*%<
  * Log 'message' at the specified logging parameters.
  *
@@ -1408,7 +1419,7 @@ dns_message_logfmtpacket(dns_message_t *message, const char *description,
 
 isc_result_t
 dns_message_buildopt(dns_message_t *msg, dns_rdataset_t **opt,
-		     unsigned int version, isc_uint16_t udpsize,
+		     unsigned int version, uint16_t udpsize,
 		     unsigned int flags, dns_ednsopt_t *ednsopts, size_t count);
 /*%<
  * Built a opt record.
@@ -1434,7 +1445,7 @@ dns_message_setclass(dns_message_t *msg, dns_rdataclass_t rdclass);
  */
 
 void
-dns_message_setpadding(dns_message_t *msg, isc_uint16_t padding);
+dns_message_setpadding(dns_message_t *msg, uint16_t padding);
 /*%<
  * Set the padding block size in the response.
  * 0 means no padding (default).
