@@ -490,7 +490,7 @@
 
 #define STACK_DIRECTION -1
 
-#define SYSTEM_TYPE "FreeBSD11.1"
+#define SYSTEM_TYPE "FreeBSD11.2"
 #define MACHINE_TYPE "i386"
 /* #undef HAVE_DTRACE */
 
@@ -529,7 +529,7 @@
 /* #undef WITH_INNODB_MEMCACHED */
 /* #undef ENABLE_MEMCACHED_SASL */
 /* #undef ENABLE_MEMCACHED_SASL_PWDB */
-/* #undef HAVE_SASL_SASL_H */
+#define HAVE_SASL_SASL_H 1
 /* #undef HAVE_HTONLL */
 
 /*
@@ -639,16 +639,16 @@
 
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 40
+#define MYSQL_VERSION_PATCH 43
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.6.40"
+#define PACKAGE_STRING "MySQL Server 5.6.43"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.6.40"
-#define VERSION "5.6.40"
+#define PACKAGE_VERSION "5.6.43"
+#define VERSION "5.6.43"
 #define PROTOCOL_VERSION 10
 
 
