@@ -50,7 +50,7 @@ except ImportError:
 
 
 class GalaxyCLI(CLI):
-    '''command to manage Ansible roles in shared repostories, the default of which is Ansible Galaxy *https://galaxy.ansible.com*.'''
+    '''command to manage Ansible roles in shared repositories, the default of which is Ansible Galaxy *https://galaxy.ansible.com*.'''
 
     SKIP_INFO_KEYS = ("name", "description", "readme_html", "related", "summary_fields", "average_aw_composite", "average_aw_score", "url")
     VALID_ACTIONS = ("delete", "import", "info", "init", "install", "list", "login", "remove", "search", "setup")
@@ -67,8 +67,10 @@ class GalaxyCLI(CLI):
         # specific to actions
         if self.action == "delete":
             self.parser.set_usage("usage: %prog delete [options] github_user github_repo")
+            self.parser.set_description("Removes the role from Galaxy. It does not remove or alter the actual GitHub repository.")
         elif self.action == "import":
             self.parser.set_usage("usage: %prog import [options] github_user github_repo")
+            self.parser.set_description("Import a role.")
             self.parser.add_option('--no-wait', dest='wait', action='store_false', default=True, help='Don\'t wait for import results.')
             self.parser.add_option('--branch', dest='reference',
                                    help='The name of a branch to import. Defaults to the repository\'s default branch (usually master)')
@@ -77,26 +79,34 @@ class GalaxyCLI(CLI):
                                    help='Check the status of the most recent import request for given github_user/github_repo.')
         elif self.action == "info":
             self.parser.set_usage("usage: %prog info [options] role_name[,version]")
+            self.parser.set_description("View more details about a specific role.")
         elif self.action == "init":
             self.parser.set_usage("usage: %prog init [options] role_name")
+            self.parser.set_description("Initialize new role with the base structure of a role.")
             self.parser.add_option('--init-path', dest='init_path', default="./",
                                    help='The path in which the skeleton role will be created. The default is the current working directory.')
-            self.parser.add_option('--container-enabled', dest='container_enabled', action='store_true', default=False,
-                                   help='Initialize the skeleton role with default contents for a Container Enabled role.')
+            self.parser.add_option('--type', dest='role_type', action='store', default='default',
+                                   help="Initialize using an alternate role type. Valid types include: 'container', 'apb' and 'network'.")
             self.parser.add_option('--role-skeleton', dest='role_skeleton', default=C.GALAXY_ROLE_SKELETON,
                                    help='The path to a role skeleton that the new role should be based upon.')
         elif self.action == "install":
             self.parser.set_usage("usage: %prog install [options] [-r FILE | role_name(s)[,version] | scm+role_repo_url[,version] | tar_file(s)]")
+            self.parser.set_description("Install Roles from file(s), URL(s) or tar file(s)")
             self.parser.add_option('-i', '--ignore-errors', dest='ignore_errors', action='store_true', default=False,
                                    help='Ignore errors and continue with the next specified role.')
             self.parser.add_option('-n', '--no-deps', dest='no_deps', action='store_true', default=False, help='Don\'t download roles listed as dependencies')
             self.parser.add_option('-r', '--role-file', dest='role_file', help='A file containing a list of roles to be imported')
+            self.parser.add_option('-g', '--keep-scm-meta', dest='keep_scm_meta', action='store_true',
+                                   default=False, help='Use tar instead of the scm archive option when packaging the role')
         elif self.action == "remove":
             self.parser.set_usage("usage: %prog remove role1 role2 ...")
+            self.parser.set_description("Delete a role from roles_path.")
         elif self.action == "list":
             self.parser.set_usage("usage: %prog list [role_name]")
+            self.parser.set_description("Show the name and version of each role installed in the roles_path.")
         elif self.action == "login":
             self.parser.set_usage("usage: %prog login [options]")
+            self.parser.set_description("Login to api.github.com server in order to use ansible-galaxy sub command such as 'import', 'delete' and 'setup'.")
             self.parser.add_option('--github-token', dest='token', default=None, help='Identify with github token rather than username and password.')
         elif self.action == "search":
             self.parser.set_usage("usage: %prog search [searchterm1 searchterm2] [--galaxy-tags galaxy_tag1,galaxy_tag2] [--platforms platform1,platform2] "
@@ -104,12 +114,13 @@ class GalaxyCLI(CLI):
             self.parser.add_option('--platforms', dest='platforms', help='list of OS platforms to filter by')
             self.parser.add_option('--galaxy-tags', dest='galaxy_tags', help='list of galaxy tags to filter by')
             self.parser.add_option('--author', dest='author', help='GitHub username')
+            self.parser.set_description("Search the Galaxy database by tags, platforms, author and multiple keywords.")
         elif self.action == "setup":
             self.parser.set_usage("usage: %prog setup [options] source github_user github_repo secret")
             self.parser.add_option('--remove', dest='remove_id', default=None,
                                    help='Remove the integration matching the provided ID value. Use --list to see ID values.')
             self.parser.add_option('--list', dest="setup_list", action='store_true', default=False, help='List all of your integrations.')
-
+            self.parser.set_description("Manage the integration between Galaxy and the given source.")
         # options that apply to more than one action
         if self.action in ['init', 'info']:
             self.parser.add_option('--offline', dest='offline', default=False, action='store_true', help="Don't query the galaxy API when creating roles")
@@ -119,7 +130,7 @@ class GalaxyCLI(CLI):
             # callback will set the value to a list.
             self.parser.add_option('-p', '--roles-path', dest='roles_path', action="callback", callback=CLI.unfrack_paths, default=C.DEFAULT_ROLES_PATH,
                                    help='The path to the directory containing your roles. The default is the roles_path configured in your ansible.cfg'
-                                        'file (/usr/local/etc/ansible/roles if not configured)', type='str')
+                                        ' file (/usr/local/etc/ansible/roles if not configured)', type='str')
         if self.action in ("init", "install"):
             self.parser.add_option('-f', '--force', dest='force', action='store_true', default=False, help='Force overwriting an existing role')
 
@@ -128,7 +139,8 @@ class GalaxyCLI(CLI):
 
         self.parser = CLI.base_parser(
             usage="usage: %%prog [%s] [--help] [options] ..." % "|".join(self.VALID_ACTIONS),
-            epilog="\nSee '%s <command> --help' for more information on a specific command.\n\n" % os.path.basename(sys.argv[0])
+            epilog="\nSee '%s <command> --help' for more information on a specific command.\n\n" % os.path.basename(sys.argv[0]),
+            desc="Perform various Role related operations.",
         )
 
         # common
@@ -211,8 +223,8 @@ class GalaxyCLI(CLI):
             company='your company (optional)',
             license='license (GPLv2, CC-BY, etc)',
             issue_tracker_url='http://example.com/issue/tracker',
-            min_ansible_version='1.2',
-            container_enabled=self.options.container_enabled
+            min_ansible_version='2.4',
+            role_type=self.options.role_type
         )
 
         # create role directory
@@ -274,7 +286,7 @@ class GalaxyCLI(CLI):
             install_info = gr.install_info
             if install_info:
                 if 'version' in install_info:
-                    install_info['intalled_version'] = install_info['version']
+                    install_info['installed_version'] = install_info['version']
                     del install_info['version']
                 role_info.update(install_info)
 
@@ -346,14 +358,7 @@ class GalaxyCLI(CLI):
                                     msg = "Unable to load data from the include requirements file: %s %s"
                                     raise AnsibleError(msg % (role_file, e))
                 else:
-                    display.deprecated("going forward only the yaml format will be supported", version="2.6")
-                    # roles listed in a file, one per line
-                    for rline in f.readlines():
-                        if rline.startswith("#") or rline.strip() == '':
-                            continue
-                        display.debug('found role %s in text file' % str(rline))
-                        role = RoleRequirement.role_yaml_parse(rline.strip())
-                        roles_left.append(GalaxyRole(self.galaxy, **role))
+                    raise AnsibleError("Invalid role requirements file")
                 f.close()
             except (IOError, OSError) as e:
                 raise AnsibleError('Unable to open %s: %s' % (role_file, str(e)))
@@ -476,15 +481,19 @@ class GalaxyCLI(CLI):
         else:
             # show all valid roles in the roles_path directory
             roles_path = self.options.roles_path
+            path_found = False
             for path in roles_path:
                 role_path = os.path.expanduser(path)
                 if not os.path.exists(role_path):
-                    raise AnsibleOptionsError("- the path %s does not exist. Please specify a valid path with --roles-path" % role_path)
+                    display.warning("- the configured path %s does not exist." % role_path)
+                    continue
                 elif not os.path.isdir(role_path):
-                    raise AnsibleOptionsError("- %s exists, but it is not a directory. Please specify a valid path with --roles-path" % role_path)
+                    display.warning("- the configured path %s, exists, but it is not a directory." % role_path)
+                    continue
                 path_files = os.listdir(role_path)
+                path_found = True
                 for path_file in path_files:
-                    gr = GalaxyRole(self.galaxy, path_file)
+                    gr = GalaxyRole(self.galaxy, path_file, path=path)
                     if gr.metadata:
                         install_info = gr.install_info
                         version = None
@@ -493,6 +502,8 @@ class GalaxyCLI(CLI):
                         if not version:
                             version = "(unknown version)"
                         display.display("- %s, %s" % (path_file, version))
+            if not path_found:
+                raise AnsibleOptionsError("- None of the provided paths was usable. Please specify a valid path with --roles-path")
         return 0
 
     def execute_search(self):
