@@ -50,7 +50,7 @@ class File
     /**
      * If TRUE, the entire file is being ignored.
      *
-     * @var string
+     * @var boolean
      */
     public $ignored = false;
 
@@ -75,6 +75,13 @@ class File
      */
     public $tokenizer = null;
 
+    /**
+     * The name of the tokenizer being used for this file.
+     *
+     * @var string
+     */
+    public $tokenizerType = 'PHP';
+
     /**
      * Was the file loaded from cache?
      *
@@ -314,6 +321,11 @@ class File
 
         $this->parse();
 
+        // Check if tokenizer errors cause this file to be ignored.
+        if ($this->ignored === true) {
+            return;
+        }
+
         $this->fixer->startFile($this);
 
         if (PHP_CODESNIFFER_VERBOSITY > 2) {
@@ -381,7 +393,7 @@ class File
                     || substr($commentTextLower, 0, 10) === '@phpcs:set'
                 ) {
                     // If the @phpcs: syntax is being used, strip the @ to make
-                    // comparisions easier.
+                    // comparisons easier.
                     if ($commentText[0] === '@') {
                         $commentText = substr($commentText, 1);
                     }
@@ -557,6 +569,7 @@ class File
             $this->tokenizer = new $tokenizerClass($this->content, $this->config, $this->eolChar);
             $this->tokens    = $this->tokenizer->getTokens();
         } catch (TokenizerException $e) {
+            $this->ignored = true;
             $this->addWarning($e->getMessage(), null, 'Internal.Tokenizer.Exception');
             if (PHP_CODESNIFFER_VERBOSITY > 0) {
                 echo "[$this->tokenizerType => tokenizer error]... ";
@@ -957,6 +970,7 @@ class File
         }
 
         // Make sure we are not ignoring this file.
+        $included = null;
         foreach ($checkCodes as $checkCode) {
             $patterns = null;
 
@@ -989,16 +1003,34 @@ class File
 
                 $pattern = '`'.strtr($pattern, $replacements).'`i';
                 $matched = preg_match($pattern, $this->path);
-                if (($matched === 1 && $excluding === true)
-                    || ($matched === 0 && $excluding === false)
-                ) {
-                    // This file path is being excluded, or not included.
+
+                if ($matched === 0) {
+                    if ($excluding === false && $included === null) {
+                        // This file path is not being included.
+                        $included = false;
+                    }
+
+                    continue;
+                }
+
+                if ($excluding === true) {
+                    // This file path is being excluded.
                     $this->ignoredCodes[$checkCode] = true;
                     return false;
                 }
+
+                // This file path is being included.
+                $included = true;
+                break;
             }//end foreach
         }//end foreach
 
+        if ($included === false) {
+            // There were include rules set, but this file
+            // path didn't match any of them.
+            return false;
+        }
+
         $messageCount++;
         if ($fixable === true) {
             $this->fixableCount++;
@@ -1338,7 +1370,7 @@ class File
             case T_SELF:
             case T_PARENT:
             case T_STATIC:
-                // Self is valid, the others invalid, but were probably intended as type hints.
+                // Self and parent are valid, static invalid, but was probably intended as type hint.
                 if (isset($defaultStart) === false) {
                     if ($typeHintToken === false) {
                         $typeHintToken = $i;
@@ -1401,7 +1433,7 @@ class File
                 // If it's null, then there must be no parameters for this
                 // method.
                 if ($currVar === null) {
-                    continue;
+                    continue 2;
                 }
 
                 $vars[$paramCount]            = [];
@@ -1456,6 +1488,7 @@ class File
      *    'is_abstract'          => false,    // true if the abstract keyword was found.
      *    'is_final'             => false,    // true if the final keyword was found.
      *    'is_static'            => false,    // true if the static keyword was found.
+     *    'has_body'             => false,    // true if the method has a body
      *   );
      * </code>
      *
@@ -1534,6 +1567,7 @@ class File
         $returnType         = '';
         $returnTypeToken    = false;
         $nullableReturnType = false;
+        $hasBody            = true;
 
         if (isset($this->tokens[$stackPtr]['parenthesis_closer']) === true) {
             $scopeOpener = null;
@@ -1569,6 +1603,9 @@ class File
                     $returnType .= $this->tokens[$i]['content'];
                 }
             }
+
+            $end     = $this->findNext([T_OPEN_CURLY_BRACKET, T_SEMICOLON], $this->tokens[$stackPtr]['parenthesis_closer']);
+            $hasBody = $this->tokens[$end]['code'] === T_OPEN_CURLY_BRACKET;
         }//end if
 
         if ($returnType !== '' && $nullableReturnType === true) {
@@ -1584,6 +1621,7 @@ class File
             'is_abstract'          => $isAbstract,
             'is_final'             => $isFinal,
             'is_static'            => $isStatic,
+            'has_body'             => $hasBody,
         ];
 
     }//end getMethodProperties()
@@ -1598,7 +1636,7 @@ class File
      * <code>
      *   array(
      *    'scope'           => 'public', // public protected or protected.
-     *    'scope_specified' => false,    // true if the scope was explicitely specified.
+     *    'scope_specified' => false,    // true if the scope was explicitly specified.
      *    'is_static'       => false,    // true if the static keyword was found.
      *   );
      * </code>
@@ -1643,6 +1681,18 @@ class File
             }
         }
 
+        // Make sure it's not a method parameter.
+        if (empty($this->tokens[$stackPtr]['nested_parenthesis']) === false) {
+            $parenthesis = array_keys($this->tokens[$stackPtr]['nested_parenthesis']);
+            $deepestOpen = array_pop($parenthesis);
+            if ($deepestOpen > $ptr
+                && isset($this->tokens[$deepestOpen]['parenthesis_owner']) === true
+                && $this->tokens[$this->tokens[$deepestOpen]['parenthesis_owner']]['code'] === T_FUNCTION
+            ) {
+                throw new TokenizerException('$stackPtr is not a class member var');
+            }
+        }
+
         $valid = [
             T_PUBLIC    => T_PUBLIC,
             T_PRIVATE   => T_PRIVATE,
@@ -1895,15 +1945,23 @@ class File
      * Returns the content of the tokens from the specified start position in
      * the token stack for the specified length.
      *
-     * @param int $start       The position to start from in the token stack.
-     * @param int $length      The length of tokens to traverse from the start pos.
-     * @param int $origContent Whether the original content or the tab replaced
-     *                         content should be used.
+     * @param int  $start       The position to start from in the token stack.
+     * @param int  $length      The length of tokens to traverse from the start pos.
+     * @param bool $origContent Whether the original content or the tab replaced
+     *                          content should be used.
      *
      * @return string The token contents.
      */
     public function getTokensAsString($start, $length, $origContent=false)
     {
+        if (is_int($start) === false || isset($this->tokens[$start]) === false) {
+            throw new RuntimeException('The $start position for getTokensAsString() must exist in the token stack');
+        }
+
+        if (is_int($length) === false || $length <= 0) {
+            return '';
+        }
+
         $str = '';
         $end = ($start + $length);
         if ($end > $this->numTokens) {
@@ -2370,12 +2428,12 @@ class File
             return false;
         }
 
-        if (isset($this->tokens[$stackPtr]['scope_closer']) === false) {
+        if (isset($this->tokens[$stackPtr]['scope_opener']) === false) {
             return false;
         }
 
-        $classCloserIndex = $this->tokens[$stackPtr]['scope_closer'];
-        $extendsIndex     = $this->findNext(T_EXTENDS, $stackPtr, $classCloserIndex);
+        $classOpenerIndex = $this->tokens[$stackPtr]['scope_opener'];
+        $extendsIndex     = $this->findNext(T_EXTENDS, $stackPtr, $classOpenerIndex);
         if (false === $extendsIndex) {
             return false;
         }
@@ -2386,7 +2444,7 @@ class File
             T_WHITESPACE,
         ];
 
-        $end  = $this->findNext($find, ($extendsIndex + 1), $classCloserIndex, true);
+        $end  = $this->findNext($find, ($extendsIndex + 1), ($classOpenerIndex + 1), true);
         $name = $this->getTokensAsString(($extendsIndex + 1), ($end - $extendsIndex - 1));
         $name = trim($name);
 
