@@ -14,7 +14,7 @@ See the License for the specific language governing permissions and
 limitations under the License.
 ]]--
 
-local ansicolors = require "rspamadm/ansicolors"
+local ansicolors = require "ansicolors"
 local local_conf = rspamd_paths['CONFDIR']
 local rspamd_util = require "rspamd_util"
 local rspamd_logger = require "rspamd_logger"
@@ -22,8 +22,9 @@ local lua_util = require "lua_util"
 local lua_stat_tools = require "lua_stat"
 local lua_redis = require "lua_redis"
 local ucl = require "ucl"
+local argparse = require "argparse"
 
-local plugins_stat = require "rspamadm/plugins_stats"
+local plugins_stat = require "plugins_stats"
 
 local rspamd_logo = [[
   ____                                     _
@@ -34,6 +35,19 @@ local rspamd_logo = [[
              |_|
 ]]
 
+local parser = argparse()
+    :name "rspamadm configwizard"
+    :description "Perform guided configuration for Rspamd daemon"
+    :help_description_margin(32)
+parser:option "-c --config"
+      :description "Path to config file"
+      :argname("<file>")
+      :default(rspamd_paths["CONFDIR"] .. "/" .. "rspamd.conf")
+parser:argument "checks"
+      :description "Checks to do (or 'list')"
+      :argname("<checks>")
+      :args "*"
+
 local redis_params
 
 local function printf(fmt, ...)
@@ -74,6 +88,30 @@ local function readline_default(greet, def_value)
   return reply
 end
 
+local function readline_expire()
+  local expire = '100d'
+  repeat
+    expire = readline_default("Expire time for new tokens [" .. expire .. "]: ",
+      expire)
+    expire = lua_util.parse_time_interval(expire)
+
+    if not expire then
+      expire = '100d'
+    elseif expire > 2147483647 then
+      printf("The maximum possible value is 2147483647 (about 68y)")
+      expire = '68y'
+    elseif expire < -1 then
+      printf("The value must be a non-negative integer or -1")
+      expire = -1
+    elseif expire ~= math.floor(expire) then
+      printf("The value must be an integer")
+      expire = math.floor(expire)
+    else
+      return expire
+    end
+  until false
+end
+
 local function print_changes(changes)
   local function print_change(k, c, where)
     printf('File: %s, changes list:', highlight(local_conf .. '/'
@@ -337,10 +375,7 @@ local function check_redis_classifier(cls, changes)
 
   local function try_convert(update_config)
     if ask_yes_no("Do you wish to convert data to the new schema?", true) then
-      local expire = readline_default("Expire time for new tokens  [default: 100d]: ",
-        '100d')
-      expire = lua_util.parse_time_interval(expire)
-
+      local expire = readline_expire()
       if not lua_stat_tools.convert_bayes_schema(parsed_redis, symbol_spam,
           symbol_ham, expire) then
         printf("Conversion failed")
@@ -360,6 +395,13 @@ local function check_redis_classifier(cls, changes)
   end
 
   local function get_version(conn)
+    conn:add_cmd("SMEMBERS", {"RS_keys"})
+
+    local ret,members = conn:exec()
+
+    -- Empty db
+    if not ret or #members == 0 then return false,0 end
+
     -- We still need to check versions
     local lua_script = [[
 local ver = 0
@@ -371,21 +413,10 @@ end
 
 return ver
 ]]
-    conn:add_cmd('EVAL', {lua_script, '1', symbol_ham})
-    local _,ver_ham = conn:exec()
+    conn:add_cmd('EVAL', {lua_script, '1', 'RS'})
+    local _,ver = conn:exec()
 
-    conn:add_cmd('EVAL', {lua_script, '1', symbol_spam})
-    local _,ver_spam = conn:exec()
-
-    -- If one of the classes is missing we still can convert the other one
-    if ver_ham == 0 and ver_spam == 0 and ver_ham ~= ver_spam then
-      printf("Current statistics versions do not match: %s -> %s, %s -> %s",
-          symbol_ham, ver_ham, symbol_spam, ver_spam)
-      printf("Cannot convert statistics")
-      return false
-    end
-
-    return true,tonumber(ver_ham)
+    return true,tonumber(ver)
   end
 
   local function check_expire(conn)
@@ -418,7 +449,13 @@ return ttl
     local r,ver = get_version(conn)
     if not r then return false end
     if ver ~= 2 then
-      printf("You are using an old schema for %s/%s", symbol_ham, symbol_spam)
+      if not ver then
+        printf('Key "RS_version" has not been found in Redis for %s/%s',
+            symbol_ham, symbol_spam)
+      else
+        printf("You are using an old schema version: %s for %s/%s",
+            ver, symbol_ham, symbol_spam)
+      end
       try_convert(true)
     else
       printf("You have configured an old schema for %s/%s but your data has new layout",
@@ -439,9 +476,12 @@ return ttl
     local r,ver = get_version(conn)
     if not r then return false end
     if ver ~= 2 then
-      printf("You have configured new schema for %s/%s but your DB has old data",
-        symbol_spam, symbol_ham)
+      printf("You have configured new schema for %s/%s but your DB has old version: %s",
+        symbol_spam, symbol_ham, ver)
       try_convert(false)
+    else
+      printf("You have configured new schema for %s/%s and your DB already has new layout (v. %s). DB conversion is not needed.",
+        symbol_spam, symbol_ham, ver)
     end
   end
 end
@@ -460,12 +500,9 @@ local function setup_statistic(cfg, changes)
     local parsed_redis = {}
     if lua_redis.try_load_redis_servers(redis_params, nil, parsed_redis) then
       printf('You have %d sqlite classifiers', #sqlite_configs)
-      local expire = readline_default("Expire time for new tokens  [default: 100d]: ",
-        '100d')
-      expire = lua_util.parse_time_interval(expire)
+      local expire = readline_expire()
 
-
-      local reset_previous = ask_yes_no("Reset previuous data?")
+      local reset_previous = ask_yes_no("Reset previous data?")
       if ask_yes_no('Do you wish to convert them to Redis?', true) then
 
         for _,cls in ipairs(sqlite_configs) do
@@ -478,7 +515,7 @@ local function setup_statistic(cfg, changes)
               return false
             end
           else
-            rspamd_logger.messagex('cannot find %s and %s, skip conversation',
+            rspamd_logger.messagex('cannot find %s and %s, skip conversion',
                 cls.db_spam, cls.db_ham)
           end
 
@@ -551,109 +588,135 @@ end
 
 
 
-return function(args, cfg)
-  local changes = {
-    l = {}, -- local changes
-    o = {}, -- override changes
-  }
+return {
+  handler = function(cmd_args)
+    local changes = {
+      l = {}, -- local changes
+      o = {}, -- override changes
+    }
 
-  local interactive_start = true
-  local checks = {}
-  local all_checks = {
-    'controller',
-    'redis',
-    'dkim',
-    'statistic',
-  }
+    local interactive_start = true
+    local checks = {}
+    local all_checks = {
+      'controller',
+      'redis',
+      'dkim',
+      'statistic',
+    }
 
-  if #args > 0 then
-    interactive_start = false
+    local opts = parser:parse(cmd_args)
+    local args = opts['checks'] or {}
 
-    for _,arg in ipairs(args) do
-      if arg == 'all' then
-        checks = all_checks
-      elseif arg == 'list' then
-        printf(highlight(rspamd_logo))
-        printf('Available modules')
-        for _,c in ipairs(all_checks) do
-          printf('- %s', c)
+    local _r,err = rspamd_config:load_ucl(opts['config'])
+    local cfg = rspamd_config:get_ucl()
+
+    if not _r then
+      rspamd_logger.errx('cannot parse %s: %s', opts['config'], err)
+      os.exit(1)
+    end
+
+    _r,err = rspamd_config:parse_rcl({'logging', 'worker'})
+    if not _r then
+      rspamd_logger.errx('cannot process %s: %s', opts['config'], err)
+      os.exit(1)
+    end
+
+    if not rspamd_config:init_modules() then
+      rspamd_logger.errx('cannot init modules when parsing %s', opts['config'])
+      os.exit(1)
+    end
+
+    if #args > 0 then
+      interactive_start = false
+
+      for _,arg in ipairs(args) do
+        if arg == 'all' then
+          checks = all_checks
+        elseif arg == 'list' then
+          printf(highlight(rspamd_logo))
+          printf('Available modules')
+          for _,c in ipairs(all_checks) do
+            printf('- %s', c)
+          end
+          return
+        else
+          table.insert(checks, arg)
         end
-        return
-      else
-        table.insert(checks, arg)
-      end
-    end
-  else
-    checks = all_checks
-  end
-
-  local function has_check(check)
-    for _,c in ipairs(checks) do
-      if c == check then
-        return true
       end
+    else
+      checks = all_checks
     end
 
-    return false
-  end
-
-  rspamd_util.umask('022')
-  if interactive_start then
-    printf(highlight(rspamd_logo))
-    printf("Welcome to the configuration tool")
-    printf("We use %s configuration file, writing results to %s",
-      highlight(cfg.config_path), highlight(local_conf))
-    plugins_stat(nil, nil)
-  end
-
-  if not interactive_start or
-      ask_yes_no("Do you wish to continue?", true) then
-
-    if has_check('controller') then
-      local controller = find_worker(cfg, 'controller')
-      if controller then
-        setup_controller(controller, changes)
+    local function has_check(check)
+      for _,c in ipairs(checks) do
+        if c == check then
+          return true
+        end
       end
+
+      return false
     end
 
-    if has_check('redis') then
-      if not cfg.redis or (not cfg.redis.servers and not cfg.redis.read_servers) then
-        setup_redis(cfg, changes)
+    rspamd_util.umask('022')
+    if interactive_start then
+      printf(highlight(rspamd_logo))
+      printf("Welcome to the configuration tool")
+      printf("We use %s configuration file, writing results to %s",
+          highlight(opts['config']), highlight(local_conf))
+      plugins_stat(nil, nil)
+    end
+
+    if not interactive_start or
+        ask_yes_no("Do you wish to continue?", true) then
+
+      if has_check('controller') then
+        local controller = find_worker(cfg, 'controller')
+        if controller then
+          setup_controller(controller, changes)
+        end
+      end
+
+      if has_check('redis') then
+        if not cfg.redis or (not cfg.redis.servers and not cfg.redis.read_servers) then
+          setup_redis(cfg, changes)
+        else
+          redis_params = cfg.redis
+        end
       else
         redis_params = cfg.redis
       end
-    else
-      redis_params = cfg.redis
-    end
 
-    if has_check('dkim') then
-      if cfg.dkim_signing and not cfg.dkim_signing.domain then
-        if ask_yes_no('Do you want to setup dkim signing feature?') then
-          setup_dkim_signing(cfg, changes)
+      if has_check('dkim') then
+        if cfg.dkim_signing and not cfg.dkim_signing.domain then
+          if ask_yes_no('Do you want to setup dkim signing feature?') then
+            setup_dkim_signing(cfg, changes)
+          end
         end
       end
-    end
 
-    if has_check('statistic') or has_check('statistics') then
-      setup_statistic(cfg, changes)
-    end
-
-    local nchanges = 0
-    for _,_ in pairs(changes.l) do nchanges = nchanges + 1 end
-    for _,_ in pairs(changes.o) do nchanges = nchanges + 1 end
-
-    if nchanges > 0 then
-      print_changes(changes)
-      if ask_yes_no("Apply changes?", true) then
-        apply_changes(changes)
-        printf("%d changes applied, the wizard is finished now", nchanges)
-        printf("*** Please reload the Rspamd configuration ***")
-      else
-        printf("No changes applied, the wizard is finished now")
+      if has_check('statistic') or has_check('statistics') then
+        setup_statistic(cfg, changes)
       end
-    else
-      printf("No changes found, the wizard is finished now")
+
+      local nchanges = 0
+      for _,_ in pairs(changes.l) do nchanges = nchanges + 1 end
+      for _,_ in pairs(changes.o) do nchanges = nchanges + 1 end
+
+      if nchanges > 0 then
+        print_changes(changes)
+        if ask_yes_no("Apply changes?", true) then
+          apply_changes(changes)
+          printf("%d changes applied, the wizard is finished now", nchanges)
+          printf("*** Please reload the Rspamd configuration ***")
+        else
+          printf("No changes applied, the wizard is finished now")
+        end
+      else
+        printf("No changes found, the wizard is finished now")
+      end
     end
-  end
-end
+  end,
+  name = 'configwizard',
+  description = parser._description,
+}
 
